@@ -19,30 +19,41 @@ usage () {
     echo -e "\033[1mUpdate installer, launch environments or create latest image files:\033[0m"
     echo -e "\033[1m-------------------------------------------------------------------\033[0m"
     echo -e "\033[1mPARAMETERS:\033[0m"
-    echo -e " \033[1m-u\033[0m               Update scripts: setup, quickinst, tz, km and helpers."
-    echo -e ""
-    if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 2000000 ]]; then
-        echo -e " \033[1m-latest\033[0m          Launch latest archboot environment (using kexec)."
-        echo -e "                  This operation needs at least \033[1m2.0 GB RAM\033[0m."
-        echo ""
-    fi
-    if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 3200000 ]]; then
-        echo -e " \033[1m-latest-install\033[0m  Launch latest archboot environment with downloaded"
-        echo -e "                  package cache (using kexec)."
-        echo -e "                  This operation needs at least \033[1m3.2 GB RAM\033[0m."
-        echo ""
-    fi
-    if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 3900000 ]]; then
-        echo -e " \033[1m-latest-image\033[0m    Generate latest image files in /archboot directory"
-        echo -e "                  This operation needs at least \033[1m3.9 GB RAM\033[0m."
-        echo ""
-    fi
-    if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 2500000 ]]; then
-        echo -e " \033[1m-launch-xfce\033[0m     Launch XFCE desktop with VNC sharing enabled."
-        echo -e "                  This operation needs at least \033[1m2.5 GB RAM\033[0m."
-        echo ""
-    fi
     echo -e " \033[1m-h\033[0m               This message."
+    echo -e ""
+    if [[ -e /usr/bin/dhcpcd ]]; then
+        echo -e " \033[1m-u\033[0m               Update scripts: setup, quickinst, tz, km and helpers."
+        echo -e ""
+    fi
+    if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 2500000 &&\
+    -e /usr/bin/setup ]]; then
+            echo -e " \033[1m-launch-xfce\033[0m     Launch XFCE desktop with VNC sharing enabled."
+            echo ""
+    fi
+    if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 3900000 &&\
+    -e /usr/bin/archboot-"${_RUNNING_ARCH}"-release.sh ]]; then
+        echo -e " \033[1m-latest-image\033[0m    Generate latest image files in /archboot directory"
+        echo ""
+    fi
+    if [[ $(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g') -lt 4400000 &&\
+        $(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g') -gt 4015000 ]]; then
+        echo -e "\033[1m\033[91mMemory check failed:\033[0m"
+        echo -e "\033[91m   - Memory gap detected: \033[1m4.0G - 4.4G RAM\033[0m"
+        echo -e "\033[91m   - Possibility of not working \033[1mkexec\033[0m\033[91m boot is given.\033[0m"
+        echo -e "\033[93m   - Please add \033[1mmore\033[0m\033[93m or \033[1mless\033[0m\033[93m RAM to enable the missing \033[1mupdate\033[0m\033[93m options.\033[0m"
+        echo ""
+    else
+        if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 2000000 &&\
+        -e /usr/bin/dhcpcd ]]; then
+            echo -e " \033[1m-latest\033[0m          Launch latest archboot environment (using kexec)."
+            echo ""
+        fi
+        if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 3200000 ]]; then
+            echo -e " \033[1m-latest-install\033[0m  Launch latest archboot environment with downloaded"
+            echo -e "                  package cache (using kexec)."
+            echo ""
+        fi
+    fi
     exit 0
 }
 
@@ -239,19 +250,19 @@ _create_initramfs() {
 _kexec () {
     if [[ $(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g') -gt 4015000 ||\
     $(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g') -lt 3200000 ]]; then
-        echo -e "\033[1mRunning kexec with new KEXEC_FILE_LOAD ...\033[0m"
+        echo -e "Running \033[1m\033[92mkexec\033[0m with \033[1mnew\033[0m KEXEC_FILE_LOAD ..."
         # works on systems with >4GB, --latest-install needs around 4400MB RAM
         # that causes a gap which can break qemu kexec or parallels desktop
         if [[ $(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g') -lt 4400000 &&\
         $(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g') -gt 4015000 ]]; then
-            echo -e "\033[91mMemory Gap Warning (4.0G - 4.4G RAM):\033[0m"
-            echo -e "\033[1m- Possibility of not working kexec boot.\033[0m"
-            echo -e "\033[1m- Please use more or less RAM.\033[0m"
-            sleep 10
+            echo -e "\033[1m\033[91mWarning:\033[0m"
+            echo -e "\033[1m\033[91m- Memory gap detected (4.0G - 4.4G RAM)\033[0m"
+            echo -e "\033[1m\033[93m- Possibility of not working kexec boot.\033[0m"
+            echo -e "\033[1m\033[93m- Please use more or less RAM.\033[0m"
         fi
         kexec -s -f /"${VMLINUZ}" --initrd="/initrd.img" --reuse-cmdline &
     else
-        echo -e "\033[1mRunning kexec with old KEXEC_LOAD ...\033[0m"
+        echo -e "Running \033[1m\033[92mkexec\033[0m with \033[1mold\033[0m KEXEC_LOAD ..."
         # works on systems with <4GB
         kexec -c -f /"${VMLINUZ}" --initrd="/initrd.img" --reuse-cmdline &
         sleep 2
